==> nextcloud-14.0.13.zip: nextcloud/apps/activity/l10n/et_EE.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Tegevused",
    "An error occurred while loading activities" : "Tegevuse laadimisel tekkis tõrge",
    "No activity yet" : "Tegevusi veel pole",
    "Load more activities" : "Lae rohkem tegevusi",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘ + C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl + C.",
    "{name} (invisible)" : "{name} (nähtamatu)",
    "{name} (restricted)" : "{name} (piiratud)",
    "Home" : "Avaleht",
    "in {path}" : "kataloogis {path}",
    "This stream will show events like additions, changes & shares" : "See voog näitab sündmusi nagu lisamised, muudatused ja jagamised",
    "There are no events for this filter" : "Selle filtri jaoks pole ühtegi sündmust",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "Open file" : "Ava fail",
    "Personal activity feed for %s" : "Isiklik tegevuste voog %s",
    "Your feed URL is invalid" : "Sinu uudisvoo URL on vigane",
    "Your settings have been updated." : "Seaded on uuendatud.",
    "Settings have been updated." : "Seaded on uuendatud.",
    "All activities" : "Kõik tegevused",
    "By others" : "Teiste poolt",
    "By you" : "Sinu poolt",
    "Hello %s" : "Tere %s",
    "Hello %s," : "Tere %s,",
    "There was some activity at %s" : "Mõningane tegevus %s",
    "_and %n more _::_and %n more _" : ["ja %n veel","ja%n veel "],
    "Mail" : "Kirjad",
    "Stream" : "Voog",
    "Activity feed" : "Tegevuste voog",
    "Send activity emails" : "Saada tegevuste kohta e-kirju",
    "Default settings" : "Vaikeseaded",
    "Configure the default activity settings for new users." : "Uute kasutajate vaiketegevuste seadete konfigureerimine.",
    "List your own actions in the stream" : "Loetle oma tegevused voos",
    "Notify about your own actions via email" : "Teavite omaenda tegevustest e-postiga",
    "You need to set up your email address before you can receive notification emails." : "Enne teavituskirjade saamist pead sa lisama oma e-posti aadressi.",
    "Send emails:" : "Saada kirjad:",
    "As soon as possible" : "Nii kiiresti kui võimalik",
    "Hourly" : "Iga tund",
    "Daily" : "Iga päev",
    "Weekly" : "Iga nädal",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Valige, milliste tegevuste jaoks soovite saada meilisõnumit ja mis peaks ilmuma aktiivsuse rakenduste voos.",
    "Choose which activities you want to see in your stream." : "Valige, milliseid tegevusi soovite voos kuvada.",
    "Settings" : "Seaded",
    "Enable RSS feed" : "Luba RSS voog",
    "RSS feed" : "RRS voog",
    "No more events to load" : "Pole rohkem sündmusi, mida laadida.",
    "Activities" : "Tegevused",
    "\"remote user\"" : "\"eemal olev kasutaja\"",
    ", " : ", ",
    "%s and %s" : "%s ja %s",
    "Files" : "Failid"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.6.zip: nextcloud/apps/activity/l10n/et_EE.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Tegevused",
    "An error occurred while loading activities" : "Tegevuse laadimisel tekkis tõrge",
    "No activity yet" : "Tegevusi veel pole",
    "Load more activities" : "Lae rohkem tegevusi",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘ + C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl + C.",
    "{name} (invisible)" : "{name} (nähtamatu)",
    "{name} (restricted)" : "{name} (piiratud)",
    "Home" : "Avaleht",
    "in {path}" : "kataloogis {path}",
    "This stream will show events like additions, changes & shares" : "See voog näitab sündmusi nagu lisamised, muudatused ja jagamised",
    "There are no events for this filter" : "Selle filtri jaoks pole ühtegi sündmust",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "Open file" : "Ava fail",
    "Personal activity feed for %s" : "Isiklik tegevuste voog %s",
    "Your feed URL is invalid" : "Sinu uudisvoo URL on vigane",
    "Your settings have been updated." : "Seaded on uuendatud.",
    "Settings have been updated." : "Seaded on uuendatud.",
    "All activities" : "Kõik tegevused",
    "By others" : "Teiste poolt",
    "By you" : "Sinu poolt",
    "Activity notification for %s" : "Tegevuse: %s, märguanne",
    "Hello %s" : "Tere %s",
    "Hello %s," : "Tere %s,",
    "There was some activity at %s" : "Mõningane tegevus %s",
    "_and %n more _::_and %n more _" : ["ja %n veel","ja%n veel "],
    "Mail" : "Kirjad",
    "Stream" : "Voog",
    "This application enables users to view actions related to their files in Nextcloud." : "See rakendus võimaldab kasutajal vaadata oma Nextcloudi failidega seonduvaid tegevsi.",
    "Activity feed" : "Tegevuste voog",
    "Send activity emails" : "Saada tegevuste kohta e-kirju",
    "Default settings" : "Vaikeseaded",
    "Configure the default activity settings for new users." : "Uute kasutajate vaiketegevuste seadete konfigureerimine.",
    "List your own actions in the stream" : "Loetle oma tegevused voos",
    "Notify about your own actions via email" : "Teavite omaenda tegevustest e-postiga",
    "You need to set up your email address before you can receive notification emails." : "Enne teavituskirjade saamist pead sa lisama oma e-posti aadressi.",
    "Send emails:" : "Saada kirjad:",
    "As soon as possible" : "Nii kiiresti kui võimalik",
    "Hourly" : "Iga tund",
    "Daily" : "Iga päev",
    "Weekly" : "Iga nädal",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Valige, milliste tegevuste jaoks soovite saada meilisõnumit ja mis peaks ilmuma aktiivsuse rakenduste voos.",
    "Choose which activities you want to see in your stream." : "Valige, milliseid tegevusi soovite voos kuvada.",
    "Settings" : "Seaded",
    "Enable RSS feed" : "Luba RSS voog",
    "RSS feed" : "RRS voog",
    "No more events to load" : "Pole rohkem sündmusi, mida laadida.",
    "\"remote user\"" : "\"eemal olev kasutaja\"",
    ", " : ", ",
    "%s and %s" : "%s ja %s",
    "Files" : "Failid"
},
"nplurals=2; plural=(n != 1);");
